Name:           metamath
Version:        0.177
Release:        1%{?dist}
Summary:        Construct mathematics from basic axioms

License:        GPLv2+
URL:            http://us.metamath.org/
Source0:        http://us.metamath.org/downloads/%{name}.tar.bz2
Source1:        http://us.metamath.org/latex/%{name}.tex

BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  tex(latex)
BuildRequires:  tex(makecell.sty)
BuildRequires:  tex(needspace.sty)
BuildRequires:  tex(tabu.sty)

Suggests:       rlwrap

%description
Metamath is a tiny language that can express theorems in abstract
mathematics, accompanied by proofs that can be verified by a computer
program.  Metamath lets you see mathematics developed in complete detail
from first principles, with absolute rigor.

%package        theories
Summary:        Existing mathematical theories in the metamath format
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

# peano.mm is GPLv2+; all other theory files are CC0
License:        GPLv2+ and CC0

%description    theories
This package contains metamath theory files for several branches of
mathematics, such as ZFC set theory, HOL, and Peano arithmetic.

%package        doc
Summary:        The Metamath book
License:        CC0
BuildArch:      noarch

%description    doc
This package contains The Metamath book, which provides an in-depth
understanding of the Metamath language and program.  The first part of
the book also includes an easy-to-read informal discussion of abstract
mathematics and computers, with references to other proof verifiers and
automated theorem provers.

%prep
%setup -q -n %{name}
cp -p %{SOURCE1} .
touch special-settings.sty

# Remove prebuilt objects
rm metamath.exe

# Do not override our choice of CFLAGS
sed -i '/Try to optimize/,/^$/d' configure.ac

# Generate the configure script
autoreconf -fi

%build
%configure CFLAGS="%{optflags} -DINLINE=inline -fwrapv"
make %{?_smp_mflags}

# Build the manual
touch metamath.ind
pdflatex metamath
pdflatex metamath
bibtex metamath
makeindex metamath.idx
pdflatex metamath
pdflatex metamath
pdflatex metamath

%install
%make_install

# Install all of the theories
cp -p *.mm %{buildroot}%{_datadir}/metamath

# Install the manual
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p %{name}.pdf %{buildroot}%{_docdir}/%{name}

%files
%doc README.TXT
%license LICENSE.TXT
%{_bindir}/metamath
%{_mandir}/man1/metamath.1*

%files theories
%{_datadir}/metamath/

%files doc
%license LICENSE.TXT
%dir %{_docdir}/metamath/
%{_docdir}/metamath/metamath.pdf

%changelog
* Sun Apr 28 2019 Jerry James <loganjerry@gmail.com> - 0.177-1
- New upstream version

* Tue Mar 26 2019 Jerry James <loganjerry@gmail.com> - 0.176-1
- New upstream version

* Sat Mar  9 2019 Jerry James <loganjerry@gmail.com> - 0.175-1
- New upstream version

* Sat Feb 23 2019 Jerry James <loganjerry@gmail.com> - 0.174-1
- New upstream version

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.172-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jan 26 2019 Jerry James <loganjerry@gmail.com> - 0.172-1
- New upstream version

* Wed Jan  2 2019 Jerry James <loganjerry@gmail.com> - 0.171-1
- New upstream version

* Tue Dec 11 2018 Jerry James <loganjerry@gmail.com> - 0.168-1
- New upstream version

* Mon Nov 19 2018 Jerry James <loganjerry@gmail.com> - 0.167-1
- New upstream version

* Sat Nov 10 2018 Jerry James <loganjerry@gmail.com> - 0.166-1
- New upstream version

* Mon Oct 29 2018 Jerry James <loganjerry@gmail.com> - 0.165-1
- New upstream version

* Sat Sep 22 2018 Jerry James <loganjerry@gmail.com> - 0.164-1
- New upstream version

* Sat Aug  4 2018 Jerry James <loganjerry@gmail.com> - 0.163-1
- New upstream version (bz 1612479)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.162-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun  4 2018 Jerry James <loganjerry@gmail.com> - 0.162-1
- New upstream version (bz 1585859)

* Tue Feb  6 2018 Jerry James <loganjerry@gmail.com> - 0.161-1
- New upstream version (bz 1541620)

* Thu Jan 25 2018 Jerry James <loganjerry@gmail.com> - 0.160-1
- New upstream version (bz 1538606)

* Thu Jan 18 2018 Jerry James <loganjerry@gmail.com> - 0.157-1
- New upstream version (bz 1536242)

* Tue Dec 19 2017 Jerry James <loganjerry@gmail.com> - 0.156-1
- New upstream version (bz 1527497)

* Mon Oct 23 2017 Jerry James <loganjerry@gmail.com> - 0.155-1
- New upstream version (bz 1504397)

* Sat Sep 30 2017 Jerry James <loganjerry@gmail.com> - 0.152-1
- New upstream version (bz 1497491)

* Tue Sep 26 2017 Jerry James <loganjerry@gmail.com> - 0.151-1
- New upstream version (bz 1495184)

* Sat Sep  2 2017 Jerry James <loganjerry@gmail.com> - 0.150-1
- New upstream version (bz 1485749)

* Wed Aug 23 2017 Jerry James <loganjerry@gmail.com> - 0.149-1
- New upstream version (bz 1484389)

* Thu Aug 17 2017 Jerry James <loganjerry@gmail.com> - 0.148-1
- New upstream version (bz 1482724)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.146-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.146-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul  3 2017 Jerry James <loganjerry@gmail.com> - 0.146-1
- New upstream version (bz 1467070)

* Tue Jun 27 2017 Jerry James <loganjerry@gmail.com> - 0.145-1
- New upstream version (bz 1462574)

* Tue May 16 2017 Jerry James <loganjerry@gmail.com> - 0.144-1
- New upstream version (bz 1450652)

* Mon May  8 2017 Jerry James <loganjerry@gmail.com> - 0.141-1
- New upstream version (bz 1448745)

* Tue Feb 14 2017 Jerry James <loganjerry@gmail.com> - 0.139-1
- New upstream version (bz 1406763)
- Install all of the theories (bz 1422091)

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.138-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Dec 29 2016 Jerry James <loganjerry@gmail.com> - 0.138-1
- New upstream version (bz 1406763)

* Mon Sep 19 2016 Jerry James <loganjerry@gmail.com> - 0.135-1
- New upstream version (bz 1377308)

* Sat Aug 27 2016 Jerry James <loganjerry@gmail.com> - 0.134-1
- New upstream version (bz 1370745)

* Fri Aug 19 2016 Jerry James <loganjerry@gmail.com> - 0.133-1
- New upstream version

* Mon Jul 18 2016 Jerry James <loganjerry@gmail.com> - 0.132-1
- New upstream version

* Tue Jun 21 2016 Jerry James <loganjerry@gmail.com> - 0.131-1
- New upstream version

* Wed May 11 2016 Jerry James <loganjerry@gmail.com> - 0.125-2
- Fix unowned directory
- Add the manual

* Fri May  6 2016 Jerry James <loganjerry@gmail.com> - 0.125-1
- Initial RPM
